@@ -93,7 +93,7 @@ def get_func_info(syntax):
 
     parse_tree = _parse_declaration(syntax)
 
-    #print(Trees.toStringTree(parse_tree, ruleNames=None, recog=parser))
+    print(Trees.toStringTree(parse_tree, ruleNames=None, recog=parser))
 
     visitor = FuncVisitor()
     visitor.visit(tree=parse_tree)
